@@ -46,7 +46,7 @@ def ip_to_location(ip):
 
     if loc.get("country_name"):
         if loc.get("city"):
-            return "{}, {}".format(loc["city"], loc["country_name"])
+            return f'{loc["city"]}, {loc["country_name"]}'
         return loc["country_name"]
 
     return None
